@@ -147,16 +147,18 @@ static bool sort_clamp_values_dec(zone_trip_limits_t limit_1,
  */
 
 int cthd_cdev::thd_cdev_set_state(int set_point, int target_temp,
-		int temperature, int state, int zone_id, int trip_id, int target_value,
-		bool force) {
+		int temperature, int state, int zone_id, int trip_id,
+		int target_state_valid, int target_value, bool force) {
 
 	time_t tm;
 	int ret;
 
 	time(&tm);
-	thd_log_debug(">>thd_cdev_set_state index:%d state:%d :%d:%d:%d force:%d\n",
-			index, state, zone_id, trip_id, target_value, force);
-	if (!force && last_state == state
+	thd_log_info(
+			">>thd_cdev_set_state index:%d state:%d :%d:%d:%d:%d force:%d\n",
+			index, state, zone_id, trip_id, target_state_valid, target_value,
+			force);
+	if (!force && last_state == state && state
 			&& (tm - last_action_time) <= debounce_interval) {
 		thd_log_debug(
 				"Ignore: delay < debounce interval : %d, %d, %d, %d, %d\n",
@@ -183,12 +185,14 @@ int cthd_cdev::thd_cdev_set_state(int set_point, int target_temp,
 
 			limit.zone = zone_id;
 			limit.trip = trip_id;
+			limit.target_state_valid = target_state_valid;
 			limit.target_value = target_value;
-			thd_log_info("Added zone %d trip %d clamp %d\n", limit.zone,
-					limit.trip, limit.target_value);
+			thd_log_info("Added zone %d trip %d clamp_valid %d clamp %d\n",
+					limit.zone, limit.trip, limit.target_state_valid,
+					limit.target_value);
 			zone_trip_limits.push_back(limit);
 
-			if (target_value != TRIP_PT_INVALID_TARGET_STATE) {
+			if (target_state_valid) {
 				if (min_state < max_state) {
 					std::sort(zone_trip_limits.begin(), zone_trip_limits.end(),
 							sort_clamp_values_asc);
@@ -199,25 +203,30 @@ int cthd_cdev::thd_cdev_set_state(int set_point, int target_temp,
 			}
 		}
 	} else {
-		thd_log_debug("zone_trip_limits.size() %lu\n", zone_trip_limits.size());
+		thd_log_debug("zone_trip_limits.size() %zu\n", (size_t)zone_trip_limits.size());
 		if (zone_trip_limits.size() > 0) {
 			int length = zone_trip_limits.size();
-			int _target_value;
+			int _target_state_valid = 0;
 			int i;
+			int erased = 0;
 
 			// Just remove the current zone requesting to turn off
 			for (i = 0; i < length; ++i) {
-				thd_log_info("match zone %d trip %d clamp %d\n",
+				thd_log_info("match zone %d trip %d clamp_valid %d clamp %d\n",
 						zone_trip_limits[i].zone, zone_trip_limits[i].trip,
+						zone_trip_limits[i].target_state_valid,
 						zone_trip_limits[i].target_value);
 
 				if (zone_trip_limits[i].zone == zone_id
 						&& zone_trip_limits[i].trip == trip_id
+						&& target_state_valid
+								== zone_trip_limits[i].target_state_valid
 						&& target_value == zone_trip_limits[i].target_value) {
-					_target_value = zone_trip_limits[i].target_value;
+					_target_state_valid = zone_trip_limits[i].target_state_valid;
 					zone_trip_limits.erase(zone_trip_limits.begin() + i);
 					thd_log_info("Erased  [%d: %d %d\n", zone_id, trip_id,
 							target_value);
+					erased = 1;
 					break;
 				}
 			}
@@ -227,12 +236,14 @@ int cthd_cdev::thd_cdev_set_state(int set_point, int target_temp,
 
 				limit = zone_trip_limits[zone_trip_limits.size() - 1];
 				target_value = limit.target_value;
+				target_state_valid = limit.target_state_valid;
 				zone_id = limit.zone;
 				trip_id = limit.trip;
-				if (target_value == TRIP_PT_INVALID_TARGET_STATE) {
+				if (!erased)
+				{
 					thd_log_info(
-							"Currently active limit by [%d: %d %d]: ignore\n",
-							zone_id, trip_id, target_value);
+							"Currently active limit by [%d: %d %d %d]: ignore\n",
+							zone_id, trip_id, target_state_valid, target_value);
 					return THD_SUCCESS;
 				}
 
@@ -241,11 +252,11 @@ int cthd_cdev::thd_cdev_set_state(int set_point, int target_temp,
 			} else {
 				// If the deleted entry has a target then on deactivation
 				// set the state to min_state
-				if (_target_value != TRIP_PT_INVALID_TARGET_STATE)
+				if (_target_state_valid)
 					target_value = get_min_state();
 			}
 		} else {
-			target_value = TRIP_PT_INVALID_TARGET_STATE;
+			target_state_valid = 0;
 		}
 	}
 
@@ -256,7 +267,7 @@ int cthd_cdev::thd_cdev_set_state(int set_point, int target_temp,
 		control_begin();
 	}
 
-	if (target_value != TRIP_PT_INVALID_TARGET_STATE) {
+	if (target_state_valid) {
 		set_curr_state_raw(target_value, zone_id);
 		curr_state = target_value;
 		ret = THD_SUCCESS;
@@ -266,13 +277,22 @@ int cthd_cdev::thd_cdev_set_state(int set_point, int target_temp,
 	} else if (pid_enable) {
 		pid_ctrl.set_target_temp(target_temp);
 		ret = pid_ctrl.pid_output(temperature);
-		ret += get_curr_state();
-		if (ret > get_max_state())
-			ret = get_max_state();
-		if (ret < get_min_state())
-			ret = get_min_state();
+		ret += get_min_state();
+
+		if (get_min_state() < get_max_state()) {
+			if (ret > get_max_state())
+				ret = get_max_state();
+			if (ret < get_min_state())
+				ret = get_min_state();
+		} else {
+			if (ret < get_max_state())
+				ret = get_max_state();
+			if (ret > get_min_state())
+				ret = get_min_state();
+		}
+
 		set_curr_state_raw(ret, zone_id);
-		thd_log_debug("Set : %d, %d, %d, %d, %d\n", set_point, temperature,
+		thd_log_info("Set : %d, %d, %d, %d, %d\n", set_point, temperature,
 				index, get_curr_state(), max_state);
 		ret = THD_SUCCESS;
 	} else {
@@ -288,7 +308,7 @@ int cthd_cdev::thd_cdev_set_state(int set_point, int target_temp,
 
 int cthd_cdev::thd_cdev_set_min_state(int zone_id, int trip_id) {
 	trend_increase = false;
-	thd_cdev_set_state(0, 0, 0, 0, zone_id, trip_id, min_state, true);
+	thd_cdev_set_state(0, 0, 0, 0, zone_id, trip_id, 1, min_state, true);
 
 	return THD_SUCCESS;
 }
